#[non_exhaustive]pub enum CsvDecodeErrorKind {
FieldCount,
Field,
HeaderMismatch,
}Expand description
The kind of a typed-CSV decoding error.
#[non_exhaustive]: new kinds may be added in a future release.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FieldCount
A record had a different number of fields than the target expected.
Field
A field could not be parsed into the target type.
HeaderMismatch
The header row did not match the target’s header.