#[non_exhaustive]pub enum CsvFromStrError {
Parse(CsvError),
Decode(CsvDecodeError),
}Expand description
The error type of from_csv_str: either the input
was not valid CSV, or a record did not match the target type.
#[non_exhaustive]: new variants may be added in a future release.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Parse(CsvError)
The input was not valid CSV.
Decode(CsvDecodeError)
The CSV parsed but a record did not match the target type.