CsvDecode

Trait CsvDecode 

pub trait CsvDecode: Sized {
    // Required method
    fn decode_fields(fields: &[&str]) -> Result<Self, CsvDecodeError>;
}
A record type that can be read from a CSV row.

Required Methods

fn decode_fields(fields: &[&str]) -> Result<Self, CsvDecodeError>

Decodes a record from its fields, or returns a CsvDecodeError.

Implementors should reject a wrong field count with CsvDecodeError::field_count.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors